"use client";

import { Input } from "@/components/ui/input";
import { Label } from "@/components/ui/label";
import { cn } from "@/lib/utils";
import { Icon } from "@iconify/react/dist/iconify.js";
import { useLocale, useTranslations } from "next-intl";
import Image from "next/image";
import React, { useCallback, useEffect, useState } from "react";

interface PhoneInputProps {
	value?: string;
	onChange?: (value: string) => void;
	id?: string;
	label?: string;
	errorMessage?: string;
	className?: string;
	inputclassName?: string;
	labelclassName?: string;
	errorclassName?: string;
	disabled?: boolean;
	readOnly?: boolean;
	placeholder?: string;
}


const countries = {
	SA: { name: "Saudi Arabia", code: "+966", flag: "🇸🇦" },
};
const PhoneInput = React.forwardRef<HTMLInputElement, PhoneInputProps>(
	({ id, className, placeholder, onChange, value, label, labelclassName, inputclassName, errorMessage, errorclassName, disabled, readOnly, ...props }, ref) => {
		const t = useTranslations();
		const locale = useLocale();
		const [phoneNumber, setPhoneNumber] = useState(value || "05");

		useEffect(() => {
			if (value !== undefined && value !== phoneNumber) {
				setPhoneNumber(formatInitialValue(value));
			}
		}, [value, phoneNumber]);

		const formatInitialValue = (val: string) => {
			let formatted = val;
			if (val.startsWith("0")) {
				formatted = val.slice(0, 10);
			} else if (val.startsWith("5")) {
				formatted = val.slice(0, 9);
			}
			else {
				formatted = "";
			}
			return formatted;
		};


		const handleInputChange = useCallback((e: React.ChangeEvent<HTMLInputElement>) => {
			let inputValue = e.target.value;

			// Allow only numbers starting with '0' or '5' or empty
			if (inputValue === "" || inputValue.startsWith("0") || inputValue.startsWith("5")) {
				if (inputValue.startsWith("0")) {
					inputValue = inputValue.slice(0, 10);
					if (inputValue.length > 1 && inputValue[1] !== "5") return;

				} else if (inputValue.startsWith("5")) {
					inputValue = inputValue.slice(0, 9);
				}

				// check the length
				if (
					(inputValue.startsWith("0") && inputValue.length > 10) ||
					(inputValue.startsWith("5") && inputValue.length > 9)
				) {
					return;
				}

				setPhoneNumber(inputValue);
				if (onChange) {
					onChange(inputValue);
				}
			}
			else return;
		}, [onChange]);


		const selectedCountry = countries["SA"];

		return (
			<div className={cn("space-y-2 rounded-md", className)} dir="ltr">
				{label && (
					<Label
						htmlFor={id}
						className={cn(labelclassName)}
					>
						{label}
					</Label>
				)}
				<div className="flex items-center">
					<div className="relative flex items-center w-[100px]">
						<div className="flex items-center gap-2 ml-3">
							<Image src={"/flags/saudi.png"} width={25} height={25} alt="sa" />
							<span className="text-black text-[14px] pr-2">{selectedCountry.code}</span>
						</div>
						<select
							value={selectedCountry.code}
							onChange={() => { }} // Make it read-only
							className={cn(
								"appearance-none px-3 py-2 border rounded-l-md bg-gray-100 text-gray-700",
								"focus:outline-none focus:ring-2 focus:ring-gray-500",
								"cursor-pointer",
								disabled && "opacity-50 cursor-not-allowed",
								readOnly && "opacity-50 cursor-not-allowed",
								"w-24",
								"hidden"
							)}
							disabled={true}

						>
							<option key={selectedCountry.code} value={selectedCountry.code}>
								{selectedCountry.code}
							</option>
						</select>
						{/* Custom dropdown arrow */}
						<div className="absolute inset-y-0 right-0 flex items-center px-1 pointer-events-none">
							<Icon icon="mdi:chevron-down" className="w-4 h-4 text-gray-400" />
						</div>
					</div>
					<Input
						type="tel"
						id={id}
						value={phoneNumber}
						onChange={handleInputChange}
						placeholder={placeholder || t("Start with 05 or 5")}
						className={cn(
							"flex-1 border-l rounded-bl-none rounded-tl-none h-11 text-black border-none",
							locale === "ar" ? "placeholder:text-right" : "placeholder:text-left",
							inputclassName,

						)}
						style={{
							borderLeft: "1px solid #cecfd1",
						}}
						disabled={disabled}
						readOnly={readOnly}
						{...props}
					/>
				</div>
				{errorMessage && (
					<p className={cn("text-red-500 text-sm", errorclassName)}>{errorMessage}</p>
				)}
			</div>
		);
	}
);





PhoneInput.displayName = "PhoneInput";

export default PhoneInput;
